@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0801';
+our $VERSION = '0.0802';
 
 use Moo;
 use strictures 2;
@@ -109,7 +109,7 @@ sub BUILD {
 
     my @scale = qw/C Db D Eb E F Gb G Ab A Bb B/;
 
-    # Make a scale position index corresponding with the given tuning
+    # Make a scale position index corresponding to the given tuning
     my @index = map { my $t = $_; first_index { $t eq $_ } @scale } @{ $self->tuning };
 
     my %notes;
@@ -145,8 +145,8 @@ sub draw {
 
     # Setup a new image
     my $i = Imager->new(
-        xsize => $SPACE + $self->strings * $SPACE - $self->strings,
-        ysize => $SPACE + $self->frets * $SPACE - $self->frets,
+        xsize => $SPACE + $self->strings * $SPACE,
+        ysize => $SPACE + $self->frets * $SPACE,
     );
     $i->box( filled => 1, color => $WHITE );
 
@@ -278,8 +278,8 @@ sub _draw_horiz {
 
     # Setup a new image
     my $i = Imager->new(
-        ysize => $SPACE + $self->strings * $SPACE - $self->strings,
-        xsize => $SPACE + $self->frets * $SPACE - $self->frets,
+        ysize => $SPACE + $self->strings * $SPACE,
+        xsize => $SPACE + $self->frets * $SPACE,
     );
     $i->box( filled => 1, color => $WHITE );
 
@@ -424,7 +424,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0801
+version 0.0802
 
 =head1 SYNOPSIS
 
@@ -597,7 +597,8 @@ Default: blue
 
   $fretboard = $dia->fretboard;
 
-A hashref of the string notes.  This is a computed attribute.
+A hashref of the string notes.  This is a computed attribute based on the given
+B<tuning>.
 
 =head2 showname
 
